============
Installation
============

At the command line::

    $ easy_install dj-test-queries

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv dj-test-queries
    $ pip install dj-test-queries
